summaryrefslogtreecommitdiff
path: root/include/ruby/impl/intern/range.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ruby/impl/intern/range.h')
-rw-r--r--include/ruby/impl/intern/range.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/ruby/impl/intern/range.h b/include/ruby/impl/intern/range.h
index c0a7297277..06b5231e42 100644
--- a/include/ruby/impl/intern/range.h
+++ b/include/ruby/impl/intern/range.h
@@ -1,5 +1,5 @@
-#ifndef RUBY3_INTERN_RANGE_H /*-*-C++-*-vi:se ft=cpp:*/
-#define RUBY3_INTERN_RANGE_H
+#ifndef RBIMPL_INTERN_RANGE_H /*-*-C++-*-vi:se ft=cpp:*/
+#define RBIMPL_INTERN_RANGE_H
/**
* @file
* @author Ruby developers <ruby-core@ruby-lang.org>
@@ -7,7 +7,7 @@
* Permission is hereby granted, to either redistribute and/or
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
* @warning Symbols prefixed with either `RUBY3` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file
* is also an implementation detail. Do not expect it to persist
@@ -23,13 +23,13 @@
#include "ruby/impl/dllexport.h"
#include "ruby/impl/value.h"
-RUBY3_SYMBOL_EXPORT_BEGIN()
+RBIMPL_SYMBOL_EXPORT_BEGIN()
/* range.c */
VALUE rb_range_new(VALUE, VALUE, int);
VALUE rb_range_beg_len(VALUE, long*, long*, long, int);
int rb_range_values(VALUE range, VALUE *begp, VALUE *endp, int *exclp);
-RUBY3_SYMBOL_EXPORT_END()
+RBIMPL_SYMBOL_EXPORT_END()
-#endif /* RUBY3_INTERN_RANGE_H */
+#endif /* RBIMPL_INTERN_RANGE_H */
@@ -7,7 +7,7 @@
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
- * @warning Symbols prefixed with either `RUBY3` or `ruby3` are
+ * @warning Symbols prefixed with either `RBIMPL` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file